"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FavouriteMealRecord = void 0;
const db_1 = require("../utils/db");
class FavouriteMealRecord {
    static getAll(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [resultsProducts] = (yield db_1.pool.execute("SELECT `favourite_products`.`id`, `favourite_meals`.`mealId`, `title`, `name`, `proteins`, `carbohydrates`, `fats`, `calories`, `amount`, `index` FROM `favourite_meals` JOIN `favourite_products` ON `favourite_meals`.`mealId` = `favourite_products`.`mealId` WHERE `favourite_meals`.`userId`=:userId ORDER BY `title`", {
                userId: id,
            }));
            return resultsProducts;
        });
    }
    static updateTitle(title, mealId) {
        return __awaiter(this, void 0, void 0, function* () {
            (yield db_1.pool.execute("UPDATE `favourite_meals` SET `title`=:title WHERE `mealId`=:id", {
                title,
                id: mealId,
            }));
        });
    }
    static updateValues(product) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `favourite_products` SET `name`=:name, `proteins`=:proteins, `carbohydrates`=:carbohydrates, `fats`=:fats, `calories`=:calories, `amount`=:amount WHERE `mealId`=:mealId AND `id`=:id", {
                mealId: product.favouriteId,
                id: product.id,
                name: product.name,
                proteins: product.proteins,
                carbohydrates: product.carbohydrates,
                fats: product.fats,
                calories: product.calories,
                amount: product.amount,
            });
        });
    }
    static add(mealData, productsData) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("INSERT INTO `favourite_meals`(`mealId`, `userId`, `title`) VALUES (:mealId, :userId, :title)", {
                mealId: mealData.mealId,
                userId: mealData.userId,
                title: mealData.title,
            });
            for (const product of productsData) {
                yield db_1.pool.execute("INSERT INTO `favourite_products`(`mealId`, `id`, `name`, `proteins`, `carbohydrates`, `fats`, `calories`, `amount`, `index`) VALUES (:mealId, :id, :name, :proteins, :carbohydrates, :fats, :calories, :amount, :index)", {
                    mealId: product.favouriteId,
                    id: product.id,
                    name: product.name,
                    proteins: product.proteins,
                    carbohydrates: product.carbohydrates,
                    fats: product.fats,
                    calories: product.calories,
                    amount: product.amount,
                    index: product.index
                });
            }
        });
    }
    static delete(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `favourite_products` WHERE `mealId` = :id", {
                id,
            });
            yield db_1.pool.execute("DELETE FROM `favourite_meals` WHERE `mealId` = :id", {
                id,
            });
        });
    }
}
exports.FavouriteMealRecord = FavouriteMealRecord;
//# sourceMappingURL=favourite-meal.record.js.map