"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProductRecord = void 0;
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class ProductRecord {
    constructor(obj) {
        this.id = obj.id;
        this.name = obj.name;
        this.proteins = Number(obj.proteins.toFixed(2));
        this.carbohydrates = Number(obj.carbohydrates.toFixed(2));
        this.fats = Number(obj.fats.toFixed(2));
        this.calories = Number(obj.calories.toFixed(2));
        this.amount = 100;
    }
    static findAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `products`"));
            return results.map((obj) => new ProductRecord(obj));
        });
    }
    static findOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `products` WHERE `id`=:id", {
                id,
            }));
            return results.length === 0 ? null : new ProductRecord(results[0]);
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute("INSERT INTO `products`  VALUES(:name, :proteins, :carbohydrates, :fats, :calories, :amount)", {
                id: this.id,
                name: this.name,
                proteins: this.proteins,
                carbohydrates: this.carbohydrates,
                fats: this.fats,
                calories: this.calories,
                amount: this.amount
            });
            return this.id;
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `products` WHERE `id`=:id", {
                id: this.id,
            });
        });
    }
}
exports.ProductRecord = ProductRecord;
//# sourceMappingURL=product.record.js.map