"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRecord = void 0;
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class UserRecord {
    constructor(obj) {
        this.id = obj.id;
        this.username = obj.username;
        this.password = obj.password;
    }
    static findOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `users` WHERE `id`=:id", {
                id,
            }));
            return results.length === 0 ? null : new UserRecord(results[0]);
        });
    }
    static findByUsername(username) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `users` WHERE `username`=:username", {
                username,
            }));
            return results.length === 0 ? null : new UserRecord(results[0]);
        });
    }
    create() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute("INSERT INTO `users` VALUES(:id, :username, :password)", {
                id: this.id,
                username: this.username,
                password: this.password,
            });
            return this.id;
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `users` SET `username` = :username, `password` = :password WHERE `id` = :id", {
                id: this.id,
                username: this.username,
                password: this.password,
            });
        });
    }
}
exports.UserRecord = UserRecord;
//# sourceMappingURL=user.record.js.map