"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.authRouter = void 0;
const express_1 = __importDefault(require("express"));
const user_record_1 = require("../records/user.record");
const bcrypt_1 = __importDefault(require("bcrypt"));
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const JWT_SECRET_1 = require("../utils/JWT_SECRET");
const error_1 = require("../utils/error");
exports.authRouter = express_1.default.Router();
exports.authRouter
    .post('/login', (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    const { username, password } = req.body;
    const user = yield user_record_1.UserRecord.findByUsername(username);
    try {
        if (user === null) {
            return next((0, error_1.createError)(403, 'Invalid username or password.'));
        }
        const isPasswordCorrect = yield bcrypt_1.default.compare(password, user.password);
        if (!isPasswordCorrect)
            return next((0, error_1.createError)(403, 'Invalid username or password.'));
        const loggedUser = {
            id: user.id,
            username,
        };
        const token = jsonwebtoken_1.default.sign({
            id: user.id,
            username,
        }, JWT_SECRET_1.JWT_SECRET);
        res
            .cookie('access_token', token, {
            httpOnly: true,
        })
            .status(200).json({
            success: true,
            loggedUser
        });
    }
    catch (e) {
        next(e);
    }
}))
    .post('/registry', (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    const { username, password } = req.body;
    try {
        const isAlreadySameUser = (yield user_record_1.UserRecord.findByUsername(username)) !== null;
        if (isAlreadySameUser)
            return next((0, error_1.createError)(403, 'User with this username already exists.'));
        if (password.length < 5)
            return next((0, error_1.createError)(403, 'Password should have at least 5 characters.'));
        const hashedPassword = yield bcrypt_1.default.hash(password, 10);
        const newUser = {
            username,
            password: hashedPassword,
        };
        yield new user_record_1.UserRecord(newUser).create();
        res.json({
            success: true,
            message: `User ${username} registered successfully.`
        });
    }
    catch (err) {
        next(err);
    }
}))
    .get('/logout', (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        res.clearCookie('access_token');
        res.status(200).json({
            success: true,
        });
    }
    catch (e) {
        next(e);
    }
}));
//# sourceMappingURL=auth.js.map