"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.userRouter = void 0;
const express_1 = __importDefault(require("express"));
const favourite_meal_record_1 = require("../records/favourite-meal.record");
const convertDatabaseDatasToFrontEndDatas_1 = require("../utils/convertDatabaseDatasToFrontEndDatas");
const verifyToken_1 = require("../utils/verifyToken");
const error_1 = require("../utils/error");
exports.userRouter = express_1.default.Router();
exports.userRouter
    .get('/:id/favourites', verifyToken_1.verifyTokenAndUserWithParams, (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    const { id } = req.params;
    try {
        const favProducts = yield favourite_meal_record_1.FavouriteMealRecord.getAll(id);
        const favMeals = (0, convertDatabaseDatasToFrontEndDatas_1.convertDatabaseDatasToFrontEndDatas)(favProducts, id);
        res.json({
            favMeals,
            success: true
        });
    }
    catch (e) {
        next(e);
    }
}))
    .put('/favourites', verifyToken_1.verifyTokenAndUserWithBody, (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    const data = req.body;
    try {
        if (data.whatToChange === 'values') {
            if (data.product.amount > 999999) {
                return next((0, error_1.createError)(400, "Too large number."));
            }
            yield favourite_meal_record_1.FavouriteMealRecord.updateValues(data.product);
        }
        if (data.whatToChange === 'title') {
            const { title, mealId } = data;
            yield favourite_meal_record_1.FavouriteMealRecord.updateTitle(title, mealId);
        }
        const favProducts = yield favourite_meal_record_1.FavouriteMealRecord.getAll(data.userId);
        const favMeals = (0, convertDatabaseDatasToFrontEndDatas_1.convertDatabaseDatasToFrontEndDatas)(favProducts, data.userId);
        res.json({
            favMeals,
            success: true,
        });
    }
    catch (e) {
        next(e);
    }
}))
    .post('/favourites', verifyToken_1.verifyTokenAndUserWithBody, (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    const data = req.body;
    try {
        const mealData = {
            title: data.title,
            mealId: data.favouriteId,
            userId: data.userId,
        };
        const productsData = data.products;
        yield favourite_meal_record_1.FavouriteMealRecord.add(mealData, productsData);
        res.status(200).json({
            success: true,
        });
    }
    catch (e) {
        next(e);
    }
}))
    .delete('/favourites', verifyToken_1.verifyTokenAndUserWithBody, (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    const data = req.body;
    try {
        yield favourite_meal_record_1.FavouriteMealRecord.delete(data.mealId);
        const favProducts = yield favourite_meal_record_1.FavouriteMealRecord.getAll(data.userId);
        const favMeals = (0, convertDatabaseDatasToFrontEndDatas_1.convertDatabaseDatasToFrontEndDatas)(favProducts, data.userId);
        res.json({
            favMeals,
            success: true,
        });
    }
    catch (e) {
        next(e);
    }
}));
//# sourceMappingURL=user.js.map